Crate use_7z

Crate use_7z 

use-7z

7-Zip archive labels, compression method labels, and extension helpers.

This crate is part of the use-archive facade workspace. It exposes 7-Zip-specific primitive labels only. It does not parse 7z headers, handle encryption, read archives, write archives, or extract files.

Example

use use_7z::{SevenZipCompressionMethod, SevenZipFormat, is_7z_filename};

assert!(is_7z_filename("bundle.7z"));
assert!(is_7z_filename("bundle.7z.001"));
assert_eq!(SevenZipFormat::SevenZip.as_str(), "7z");
assert_eq!(SevenZipCompressionMethod::Lzma2.as_str(), "lzma2");

7-Zip archive labels and compression method metadata for RustUse.

Enums

SevenZipCompressionMethod
7-Zip compression method labels.
SevenZipFormat
7-Zip archive format labels.

Constants

SEVEN_ZIP_EXTENSION
Common 7-Zip archive extension.
SEVEN_ZIP_EXTENSIONS
Common 7-Zip-related extensions.
SEVEN_ZIP_FIRST_VOLUME_EXTENSION
Common first split-volume 7-Zip extension.

Functions

is_7z_extension
Returns whether extension is a known 7-Zip extension label.
is_7z_filename
Returns whether name has a known 7-Zip filename encoding.